==> openttd_1.10.3.orig.tar.xz: openttd-1.10.3/src/table/genland.h <==
/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file genland.h Table used to generate deserts and/or rain forests. */

#define M(x, y) {x,  y}

static const TileIndexDiffC _make_desert_or_rainforest_data[] = {
	M(-5, -6),
	M(-4, -6),
	M(-3, -6),
	M(-2, -6),
	M(-1, -6),
	M( 0, -5),
	M( 1, -5),
	M( 2, -5),
	M( 3, -5),
	M( 4, -5),
	M( 5, -5),
	M(-5, -5),
	M(-4, -5),
	M(-3, -5),
	M(-2, -5),
	M(-1, -5),
	M( 0, -4),
	M( 1, -4),
	M( 2, -4),
	M( 3, -4),
	M( 4, -4),
	M( 5, -4),
	M(-5, -4),
	M(-4, -4),
	M(-3, -4),
	M(-2, -4),
	M(-1, -4),
	M( 0, -3),
	M( 1, -3),
	M( 2, -3),
	M( 3, -3),
	M( 4, -3),
	M( 5, -3),
	M(-5, -3),
	M(-4, -3),
	M(-3, -3),
	M(-2, -3),
	M(-1, -3),
	M( 0, -2),
	M( 1, -2),
	M( 2, -2),
	M( 3, -2),
	M( 4, -2),
	M( 5, -2),
	M(-5, -2),
	M(-4, -2),
	M(-3, -2),
	M(-2, -2),
	M(-1, -2),
	M( 0, -1),
	M( 1, -1),
	M( 2, -1),
	M( 3, -1),
	M( 4, -1),
	M( 5, -1),
	M(-5, -1),
	M(-4, -1),
	M(-3, -1),
	M(-2, -1),
	M(-1, -1),
	M( 0,  0),
	M( 1,  0),
	M( 2,  0),
	M( 3,  0),
	M( 4,  0),
	M( 5,  0),
	M(-5,  0),
	M(-4,  0),
	M(-3,  0),
	M(-2,  0),
	M(-1,  0),
	M( 0,  1),
	M( 1,  1),
	M( 2,  1),
	M( 3,  1),
	M( 4,  1),
	M( 5,  1),
	M(-5,  1),
	M(-4,  1),
	M(-3,  1),
	M(-2,  1),
	M(-1,  1),
	M( 0,  2),
	M( 1,  2),
	M( 2,  2),
	M( 3,  2),
	M( 4,  2),
	M( 5,  2),
	M(-5,  2),
	M(-4,  2),
	M(-3,  2),
	M(-2,  2),
	M(-1,  2),
	M( 0,  3),
	M( 1,  3),
	M( 2,  3),
	M( 3,  3),
	M( 4,  3),
	M( 5,  3),
	M(-5,  3),
	M(-4,  3),
	M(-3,  3),
	M(-2,  3),
	M(-1,  3),
	M( 0,  4),
	M( 1,  4),
	M( 2,  4),
	M( 3,  4),
	M( 4,  4),
	M( 5,  4),
	M(-5,  4),
	M(-4,  4),
	M(-3,  4),
	M(-2,  4),
	M(-1,  4),
	M( 0,  5),
	M( 1,  5),
	M( 2,  5),
	M( 3,  5),
	M( 4,  5),
	M( 5,  5),
	M( 6, -3),
	M(-6, -4),
	M(-3,  5),
	M(-3, -7),
	M( 6, -2),
	M(-6, -3),
	M(-2,  5),
	M(-2, -7),
	M( 6, -1),
	M(-6, -2),
	M(-1,  5),
	M(-1, -7),
	M( 6,  0),
	M(-6, -1),
	M( 0,  6),
	M( 0, -6),
	M( 6,  1),
	M(-6,  0),
	M( 1,  6),
	M( 1, -6),
	M( 6,  2),
	M(-6,  1),
	M( 2,  6),
	M( 2, -6),
	M( 6,  3),
	M(-6,  2),
	M( 3,  6),
	M( 3, -6)
};



#undef M

==> openttd_14.1.orig.tar.xz: openttd-14.1/src/table/genland.h <==
/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file genland.h Table used to generate deserts and/or rain forests. */

#define M(x, y) {x,  y}

static const TileIndexDiffC _make_desert_or_rainforest_data[] = {
	M(-5, -5),
	M(-4, -5),
	M(-3, -5),
	M(-2, -5),
	M(-1, -5),
	M( 0, -5),
	M( 1, -5),
	M( 2, -5),
	M( 3, -5),
	M( 4, -5),
	M( 5, -5),
	M(-5, -4),
	M(-4, -4),
	M(-3, -4),
	M(-2, -4),
	M(-1, -4),
	M( 0, -4),
	M( 1, -4),
	M( 2, -4),
	M( 3, -4),
	M( 4, -4),
	M( 5, -4),
	M(-5, -3),
	M(-4, -3),
	M(-3, -3),
	M(-2, -3),
	M(-1, -3),
	M( 0, -3),
	M( 1, -3),
	M( 2, -3),
	M( 3, -3),
	M( 4, -3),
	M( 5, -3),
	M(-5, -2),
	M(-4, -2),
	M(-3, -2),
	M(-2, -2),
	M(-1, -2),
	M( 0, -2),
	M( 1, -2),
	M( 2, -2),
	M( 3, -2),
	M( 4, -2),
	M( 5, -2),
	M(-5, -1),
	M(-4, -1),
	M(-3, -1),
	M(-2, -1),
	M(-1, -1),
	M( 0, -1),
	M( 1, -1),
	M( 2, -1),
	M( 3, -1),
	M( 4, -1),
	M( 5, -1),
	M(-5,  0),
	M(-4,  0),
	M(-3,  0),
	M(-2,  0),
	M(-1,  0),
	M( 0,  0),
	M( 1,  0),
	M( 2,  0),
	M( 3,  0),
	M( 4,  0),
	M( 5,  0),
	M(-5,  1),
	M(-4,  1),
	M(-3,  1),
	M(-2,  1),
	M(-1,  1),
	M( 0,  1),
	M( 1,  1),
	M( 2,  1),
	M( 3,  1),
	M( 4,  1),
	M( 5,  1),
	M(-5,  2),
	M(-4,  2),
	M(-3,  2),
	M(-2,  2),
	M(-1,  2),
	M( 0,  2),
	M( 1,  2),
	M( 2,  2),
	M( 3,  2),
	M( 4,  2),
	M( 5,  2),
	M(-5,  3),
	M(-4,  3),
	M(-3,  3),
	M(-2,  3),
	M(-1,  3),
	M( 0,  3),
	M( 1,  3),
	M( 2,  3),
	M( 3,  3),
	M( 4,  3),
	M( 5,  3),
	M(-5,  4),
	M(-4,  4),
	M(-3,  4),
	M(-2,  4),
	M(-1,  4),
	M( 0,  4),
	M( 1,  4),
	M( 2,  4),
	M( 3,  4),
	M( 4,  4),
	M( 5,  4),
	M(-5,  5),
	M(-4,  5),
	M(-3,  5),
	M(-2,  5),
	M(-1,  5),
	M( 0,  5),
	M( 1,  5),
	M( 2,  5),
	M( 3,  5),
	M( 4,  5),
	M( 5,  5),
	M( 6, -3),
	M(-6, -3),
	M(-3,  6),
	M(-3, -6),
	M( 6, -2),
	M(-6, -2),
	M(-2,  6),
	M(-2, -6),
	M( 6, -1),
	M(-6, -1),
	M(-1,  6),
	M(-1, -6),
	M( 6,  0),
	M(-6,  0),
	M( 0,  6),
	M( 0, -6),
	M( 6,  1),
	M(-6,  1),
	M( 1,  6),
	M( 1, -6),
	M( 6,  2),
	M(-6,  2),
	M( 2,  6),
	M( 2, -6),
	M( 6,  3),
	M(-6,  3),
	M( 3,  6),
	M( 3, -6)
};



#undef M
